package bankkonto;

/**
 * Title:        Bankkonto - Bank
 * Description:  einfache CORBA / ORB Anwendung:
 * ein Bankserver mit mehreren Clients
 * Copyright:    Copyright (c) 2000
 * Company:      Joller-Voss GmbH
 * @author J.M.Joller
 * @version 1.0
 */

/*
Bank Konto Server
 */

import Bank.*;
import org.omg.CORBA.*;
import org.omg.CosNaming.*;

public class BankKonto extends _KontoImplBase implements Konto {
  protected String name;
  protected int ssn;
  protected float kontostand;

  public BankKonto(String name, int ssn) {
    this.name = name;
    this.ssn = ssn;
    kontostand = 100;
    System.out.println("[Bank]Konten werden mit Kontostand 100 initialisiert");
  }

  public synchronized void abheben (float betrag) throws Bank.UngenuegenderKontostand {
    if (kontostand < betrag)
      throw new Bank.UngenuegenderKontostand(kontostand);
    kontostand -= betrag;
    System.out.println("[Bank]Es wurde der Betrag "+betrag+" abgehoben. Neuer Kontostand: "+kontostand);
  }

  public synchronized void einzahlen (float betrag) {
    kontostand += betrag;
    System.out.println("[Bank]Es wurde der Betrag "+betrag+" eingezahlt. Neuer Kontostand: "+kontostand);
  }

  public String name () {
    return name;
  }

  public void name (String name) {
    this.name = name;
  }

  public int ssn () {
    return ssn;
  }

  public float kontostand() {
    return kontostand;
  }

  public static void main (String[] args) throws UserException, InterruptedException {
    System.out.println("[Bank]Initialisierung");
    ORB orb = ORB.init (args, null);

    BankKonto klausheinrich = new BankKonto("Klaus Heinrich", 123456789);
    orb.connect (klausheinrich);
    System.out.println("[Bank]Konto fuer Klaus Heinrich, Kontonummer 123456789, wurde eroeffnet");

    org.omg.CORBA.Object nameService_ =
      orb.resolve_initial_references ("NameService");
    NamingContext nameService = NamingContextHelper.narrow (nameService_);

    NameComponent name = new NameComponent (klausheinrich.name (), "Konto");
    NameComponent[] path = { name };
    nameService.rebind (path, klausheinrich);

    Thread.currentThread ().join ();
  }
}
