// Skizze eines Flugreservations-Servers mit CORBA Anbindung
import org.omg.CosNaming.*; 
import org.omg.CosNaming.NamingContextPackage.*; 
import org.omg.CORBA.*; 
// weitere Imports
import ...;

class AirlineServer {
	static int servicePort = 4491;
	
	public static void main(String arg[]) {
		KundenRef 			kunde = null;
		FlugRef 			flug  = null;
		KundenReservationsRef 	resv = null;

		// Usage prfen
		if (arg.length <=0) {
			System.err.println("Usage:");
			System.err.println("java AirlineServer <hostname der Datenbank>");
			System.exit(1);
		}

		//kreiere eine Implementation der Objekte und publiziere sie
		try {
			kunde =
				KundenSkeleton.kreiereRef(new KundenImpl(db) );
			flug =
				FlugSkeleton.kreiereRef(new FlugImpl(db) );
			resv = 
 				KundenReservationSkeleton.kreiereRef(
 					new KundenReservationImpl(db) );
		} catch (Exception e) {
			System.err.println("[Implementation der Objekte] Exception");
		}

		// DB
		Database db = null;
		try {
			// Datenbank Instanz
			db = new Database(arg[0]);
		} catch (Exception e) {
			System.err.println([Datenbank] Error : DB Instanz");
			System.exit(1);
		}

		// Publish :extern bekanntmachen
		try {
			// binde jedes Objekt an einen Service Namen
			// kreiere und initialisiere den ORB 
			ORB orb = ORB.init(servicePort, null); 
			// registriere die Referenzen beim ORB 
			orb.connect(kunde); 
			orb.connect(flug); 
			orb.connect(resv); 

			// bestimme die Wurzel des Naming Context 
			org.omg.CORBA.Object objRef = orb.resolve_initial_references("NameService"); 
			NamingContext ncRef = NamingContextHelper.narrow(objRef); 

			// binde die Objekt Referenz im Naming Context 
			NameComponent nc = new NameComponent("FlugKunde", ""); 
			NameComponent nc = new NameComponent("Flug", ""); 
			NameComponent nc = new NameComponent("FlugReservation", ""); 

			NameComponent path[] = {nc}; 
			ncRef.rebind(path, kunde); 
			ncRef.rebind(path, flug); 
			ncRef.rebind(path, resv); 

			// warte auf Kunden; sync ist ein dummy Objekt zur Synchronisation
			java.lang.Object sync = new java.lang.Object(); 
			synchronized (sync) { 
				sync.wait(); 
			} 
		} catch (Exception e) { 
			System.err.println("[FlugReservationsServer] ERROR: " + e); 
 			e.printStackTrace(System.out); 
		} 
	}
}
